# TODO check that no license information gets lost
{ fetchurl, stdenv, python, go, cmake, vim, vimUtils, perl, ruby, unzip
, which, fetchgit, llvmPackages
, xkb_switch, rustracerd, fzf
, python3, boost, icu
, ycmd
, pythonPackages, python3Packages
, Cocoa ? null, git
}:

let

inherit (vimUtils.override {inherit vim;}) rtpPath addRtp buildVimPlugin
  buildVimPluginFrom2Nix vimHelpTags;
in

# TL;DR
# Add your plugin to ./vim-plugin-names
# Regenerate via `nix-shell -p vimPlugins.pluginnames2nix --command "vim-plugin-names-to-nix"`
# Copy the generated expression(s) into this file.
# If plugin is complicated then make changes to ./vim2nix/additional-nix-code

# This attrs contains two sections:
# The first contains plugins added manually, the second contains plugins
# generated by call nix#ExportPluginsForNix.
# Documentation & usage see vim-utils.nix.
# attribute names should be the same as used by vim-pi to make dependency
# resolution work
rec {
  # This is not a plugin, it provides bin/vim-open-buffer-with-plugins-derivations
  # which recreates this the following derivations based on ./vim-plugin-names
  pluginnames2nix = vimUtils.pluginnames2Nix {
    name = "vim-plugin-names-to-nix";
    namefiles = [./vim-plugin-names];
  };

  # Section I
  vim-addon-vim2nix = vim2nix;

  vim2nix = buildVimPluginFrom2Nix { # use it to update plugins
    name = "vim2nix";
    src = ./vim2nix;
    dependencies = ["vim-addon-manager"];
  };


  # Section II
  # Update with vimUtils.vimPlugins.pluginnames2Nix command

  # aliasess
  "sourcemap.vim"     = sourcemap;
  Colour_Sampler_Pack = Colour-Sampler-Pack;
  YouCompleteMe       = youcompleteme;
  airline             = vim-airline;
  alternative         = a-vim; # backwards compat, added 2014-10-21
  calendar            = calendar-vim;
  coffee-script       = vim-coffee-script;
  coffeeScript        = coffee-script; # backwards compat, added 2014-10-18
  colors-solarized    = Solarized;
  colorsamplerpack    = Colour_Sampler_Pack;
  command_T           = command-t; # backwards compat, added 2014-10-18
  css_color_5056      = vim-css-color;
  ctrlp               = ctrlp-vim;
  easy-align          = vim-easy-align;
  easymotion          = vim-easymotion;
  eighties            = vim-eighties;
  ghc-mod-vim         = ghcmod;
  gist-vim            = Gist;
  gitgutter           = vim-gitgutter;
  gundo               = gundo-vim;
  Gundo               = gundo-vim; # backwards compat, added 2015-10-03
  haskellConceal      = haskellconceal; # backwards compat, added 2014-10-18
  haskellconceal      = vim-haskellconceal;
  haskellConcealPlus  = vim-haskellConcealPlus;
  hier                = vim-hier;
  hlint-refactor      = hlint-refactor-vim;
  hoogle              = Hoogle;
  ipython             = vim-ipython;
  latex-live-preview  = vim-latex-live-preview;
  multiple-cursors    = vim-multiple-cursors;
  necoGhc             = neco-ghc; # backwards compat, added 2014-10-18
  neocomplete         = neocomplete-vim;
  neosnippet          = neosnippet-vim;
  nerdcommenter       = The_NERD_Commenter;
  nerdtree            = The_NERD_tree;
  polyglot            = vim-polyglot;
  quickrun            = vim-quickrun;
  repeat              = vim-repeat;
  signature           = vim-signature;
  stylish-haskell     = vim-stylish-haskell;
  stylishHaskell      = stylish-haskell; # backwards compat, added 2014-10-18
  supertab            = Supertab;
  syntastic           = Syntastic;
  tabular             = Tabular;
  tagbar              = Tagbar;
  thumbnail           = thumbnail-vim;
  tmux-navigator      = vim-tmux-navigator;
  tmuxNavigator       = tmux-navigator; # backwards compat, added 2014-10-18
  tslime              = tslime-vim;
  unite               = unite-vim;
  vimproc             = vimproc-vim;
  vimshell            = vimshell-vim;
  watchdogs           = vim-watchdogs;
  webapi-vim          = WebAPI;
  wombat256           = wombat256-vim; # backwards compat, added 2015-7-8
  yankring            = YankRing;

  fzfWrapper = buildVimPluginFrom2Nix {
    name = fzf.name;
    src = fzf.src;
    dependencies = [];
  };

  # --- generated packages bellow this line ---

  CSApprox = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "CSApprox-2013-07-26";
    src = fetchgit {
      url = "git://github.com/godlygeek/csapprox";
      rev = "7981dac51d8b6776985aa08cb7b5ee98ea7f2ddd";
      sha256 = "08g4x6nnd6hkgm2daa5ihhz75pcdx3jzzv8rfjls80qajlhx5rf6";
    };
    dependencies = [];

  };

  CheckAttach = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "CheckAttach-2017-03-15";
    src = fetchgit {
      url = "git://github.com/chrisbra/CheckAttach";
      rev = "b583efd45e03902438a55299623390a0f9253513";
      sha256 = "0j1nx8ryrlixisd8z2d24k1xk2yrqk4i0ar8m4vq3jlr74309a34";
    };
    dependencies = [];

  };

  Gist = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Gist-2016-10-10";
    src = fetchgit {
      url = "git://github.com/mattn/gist-vim";
      rev = "f0d63579eab7548cf12f979dc52ef5a370ecbe63";
      sha256 = "06nix49j4inxy3rkcv32f4ka89g4crqwfqnrm3b76iwwky8m2p17";
    };
    dependencies = [];

  };

  Hoogle = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Hoogle-2017-03-01";
    src = fetchgit {
      url = "git://github.com/Twinside/vim-hoogle";
      rev = "cfb0c864dbacf6f916ba05c4a688e21154aa971b";
      sha256 = "0gddyh47gwy684kjs9yxfnc0lg8jq9w5pdyv3yrvypyiqi51vw1b";
    };
    dependencies = [];

  };

  Solarized = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Solarized-2011-05-09";
    src = fetchgit {
      url = "git://github.com/altercation/vim-colors-solarized";
      rev = "528a59f26d12278698bb946f8fb82a63711eec21";
      sha256 = "05d3lmd1shyagvr3jygqghxd3k8a4vp32723fvxdm57fdrlyzcm1";
    };
    dependencies = [];

  };

  Supertab = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Supertab-2017-06-20";
    src = fetchgit {
      url = "git://github.com/ervandew/supertab";
      rev = "22aac5c2cb6a8ebe906bf1495eb727717390e62e";
      sha256 = "1m70rx9ba2aqydfr9yxsrff61qyzmnda24qkgn666ypnsai7cfbn";
    };
    dependencies = [];

  };

  Syntastic = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Syntastic-2017-07-07";
    src = fetchgit {
      url = "git://github.com/scrooloose/syntastic";
      rev = "e1161a723a353db99780f9a9351340df7abbb106";
      sha256 = "00gvx33yz199n7lynli0fb8cf58lb5cs0jxrqggjjy261xv2lcq1";
    };
    dependencies = [];

  };

  Tabular = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Tabular-2016-05-04";
    src = fetchgit {
      url = "git://github.com/godlygeek/tabular";
      rev = "00e1e7fcdbc6d753e0bc8043e0d2546fa81bf367";
      sha256 = "185jpisk9hamcwb6aiavdzjdbbigzdra8f4mgs98r9cm9j448xkz";
    };
    dependencies = [];

  };

  Tagbar = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Tagbar-2017-06-15";
    src = fetchgit {
      url = "git://github.com/majutsushi/tagbar";
      rev = "f5792732de16b8a2cc202f920e363eb413d7241d";
      sha256 = "188xdmrp2g7bfzg95pv1qa2l17sqwy1g2p4syj7546fksddmwgms";
    };
    dependencies = [];

  };

  The_NERD_Commenter = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "The_NERD_Commenter-2017-04-07";
    src = fetchgit {
      url = "git://github.com/scrooloose/nerdcommenter";
      rev = "285902752f7ab2052ac700a6d29b263dd5788afb";
      sha256 = "1hd5ibpvxra8asr4zp0l68wc4djjgfbvh7kzmxc1r7jqr70wj8dl";
    };
    dependencies = [];

  };

  The_NERD_tree = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "The_NERD_tree-2017-07-17";
    src = fetchgit {
      url = "git://github.com/scrooloose/nerdtree";
      rev = "e2a9929bbea0ec2050f2ea44b7e7bae3ccac66e6";
      sha256 = "03mygl8ic4awx4js04x0nw2l96kjv4vsldkgrdx0n43sh5i4z7nk";
    };
    dependencies = [];

  };

  UltiSnips = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "UltiSnips-2017-06-30";
    src = fetchgit {
      url = "git://github.com/SirVer/ultisnips";
      rev = "423f264e753cec260b4f14455126e6db7ba429af";
      sha256 = "19g3k0nqzizv39rxwgkca9n2gsd19z2wwsmicr0zcgnf50nhkznh";
    };
    dependencies = [];

  };

  VimOutliner = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "VimOutliner-2017-05-03";
    src = fetchgit {
      url = "git://github.com/vimoutliner/vimoutliner";
      rev = "fd2ca709acc161a9e65e75577c2bfefde173401a";
      sha256 = "13cqhajfz6rag7qwj2rws5gjs1f2jlrb2s30kyjrx227i05vikkn";
    };
    dependencies = [];

  };

  WebAPI = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "WebAPI-2017-04-26";
    src = fetchgit {
      url = "git://github.com/mattn/webapi-vim";
      rev = "e76f2da9a8f292a999a95ae688534f76c2dca9bd";
      sha256 = "02970g7blj478vid88gayba39rdcm9236nigkrijapyf5rd24zhh";
    };
    dependencies = [];

  };

  YankRing = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "YankRing";
    src = fetchurl {
      url = "http://www.vim.org/scripts/download_script.php?src_id=23487";
      name = "yankring_190.zip";
      sha256 = "0nnxpsfjp2p9jvs3y5ynnd5s56snz9927zdp9bgmay2jgxfmp0si";
    };
    buildInputs = [ unzip ];
    dependencies = [];
    meta = {
       url = "http://www.vim.org/scripts/script.php?script_id=1234";
    };

    sourceRoot = ".";
  };

  clang_complete = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "clang_complete-2017-07-15";
    src = fetchgit {
      url = "git://github.com/Rip-Rip/clang_complete";
      rev = "c41eea05317526a4ddd3bd389f3723390b196d4d";
      sha256 = "0bfalbzhy3n1k8bsvnh6aykgj6d17n6qgi9ahp0d8plvbjjvfw6j";
    };
    dependencies = [];
    # In addition to the arguments you pass to your compiler, you also need to
    # specify the path of the C++ std header (if you are using C++).
    # These usually implicitly set by cc-wrapper around clang (pkgs/build-support/cc-wrapper).
    # The linked ruby code shows generates the required '.clang_complete' for cmake based projects
    # https://gist.github.com/Mic92/135e83803ed29162817fce4098dec144
    # as an alternative you can execute the following command:
    # $ eval echo $(nix-instantiate --eval --expr 'with (import <nixpkgs>) {}; clang.default_cxx_stdlib_compile')
    preFixup = ''
      substituteInPlace "$out"/share/vim-plugins/clang_complete/plugin/clang_complete.vim \
        --replace "let g:clang_library_path = '' + "''" + ''" "let g:clang_library_path='${llvmPackages.clang.cc}/lib/libclang.so'"
    '';
  };

  commentary = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "commentary-2017-03-12";
    src = fetchgit {
      url = "git://github.com/tpope/vim-commentary";
      rev = "be79030b3e8c0ee3c5f45b4333919e4830531e80";
      sha256 = "1msbmbz96wa88ymjvcrbr07mxdrsjy1w2hl7z4pihf318ryq98cm";
    };
    dependencies = [];

  };

  ctrlp-cmatcher = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "ctrlp-cmatcher-2015-10-15";
    src = fetchgit {
      url = "git://github.com/JazzCore/ctrlp-cmatcher";
      rev = "6c36334f106b6fd981d23e724e9a618734cab43a";
      sha256 = "1573kd6xf3n8sxlz2j4zadai4rnc7k3s9c54648yfzickwn57d8q";
    };
    dependencies = [];
    buildInputs = [ python ];
    buildPhase = ''
      patchShebangs .
      ./install.sh
    '';
  };

  ctrlp-py-matcher = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "ctrlp-py-matcher-2017-01-05";
    src = fetchgit {
      url = "git://github.com/FelikZ/ctrlp-py-matcher";
      rev = "a0710a4937ab9dc10bc0a8b56b41fcc88534147c";
      sha256 = "198y8998sx2maarn2vawx8hqldsfbnn4i6rlg56qw6brsrssssx2";
    };
    dependencies = [];

  };

  ctrlp-z = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "ctrlp-z-2015-10-17";
    src = fetchgit {
      url = "git://github.com/amiorin/ctrlp-z";
      rev = "d1a69ec623ce24b9a30fc8fe3cd468c322b03026";
      sha256 = "16nsj1g8lqmyizlb5ijwhf4dsmh0xv1kwqq6jxvhaf55vfga82yl";
    };
    dependencies = [];

  };

  extradite = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "extradite-2015-09-22";
    src = fetchgit {
      url = "git://github.com/int3/vim-extradite";
      rev = "52326f6d333cdbb9e9c6d6772af87f4f39c00526";
      sha256 = "0c89i0spvdm9vi65q15qcmsfmwa9rds2wmaq1kf6s7q7ywvs6w8i";
    };
    dependencies = [];

  };

  fugitive = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "fugitive-2017-07-12";
    src = fetchgit {
      url = "git://github.com/tpope/vim-fugitive";
      rev = "913fff1cea3aa1a08a360a494fa05555e59147f5";
      sha256 = "1qxzxk5szm25r7wi39n5s91fjnjgz5xib67risjcwhk6jdv0vzyd";
    };
    dependencies = [];

  };

  ghcmod = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "ghcmod-2016-06-19";
    src = fetchgit {
      url = "git://github.com/eagletmt/ghcmod-vim";
      rev = "1d192d13d68ab59f9f46497a0909bf24a7b7dfff";
      sha256 = "0bzahgzagnf0a9zv86jhdf8nc3p0yfz9izv5n3lc8gc12cp47d0a";
    };
    dependencies = [];

  };

  vim-auto-save = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-auto-save-2017-03-10";
    src = fetchgit {
      url = "https://github.com/907th/vim-auto-save";
      rev = "a81dea26d2a62dbe1a0f89aba5834aee40a89512";
      sha256 = "16ljzp2rww9c13pl2ci2pqri1774qp3yhhh042n7vqxcwy80kjjc";
    };
    dependencies = [];

  };

  vim-autoformat = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-autoformat-2017-06-26";
    src = fetchgit {
      url = "https://github.com/Chiel92/vim-autoformat";
      rev = "ad189cdde5a50699a1d6b2b4b669e73942e47710";
      sha256 = "0jk1qigvz2xkpr13ii0pg0nszrnzwn51gckxjvgaqwbsz967ccsj";
    };
    dependencies = [];

  };

  vim-nix = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-nix-2017-04-30";
    src = fetchgit {
      url = "https://github.com/LnL7/vim-nix";
      rev = "867488a04c2ddc47f0f235f37599a06472fea299";
      sha256 = "1mwc06z9q45cigyxd0r9qnfs4ph6lbcwx50rf5lmpavakcn3vqir";
    };
    dependencies = [];

  };

  tsuquyomi = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "tsuquyomi-2017-05-31";
    src = fetchgit {
      url = "https://github.com/Quramy/tsuquyomi";
      rev = "46dfcd72b9701a52331349ba0d5c7596167093ab";
      sha256 = "12rvkc3wf959siijrgld56xvfhgacglxb69z4q567fsjv3ynqnrv";
    };
    dependencies = [];

  };

  deoplete-nvim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "deoplete-nvim-2017-07-22";
    src = fetchgit {
      url = "https://github.com/Shougo/deoplete.nvim";
      rev = "5cef0e6b607d3acb742d1de07a4ddd3a5bfa3036";
      sha256 = "0mh8zjaw369djffi1vzy124pwnrcxg4pbyjnhy3pq2j6k579znc2";
    };
    dependencies = [];

  };

  Spacegray-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Spacegray-vim-2017-05-05";
    src = fetchgit {
      url = "https://github.com/ajh17/Spacegray.vim";
      rev = "95a5adbbbba7fb641af847d8666b8cad20431333";
      sha256 = "10p02n4arml1b4ah0bz754ifvkqnbms4j0wlgzqs5azb20y2kliv";
    };
    dependencies = [];

  };

  nerdtree-git-plugin = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "nerdtree-git-plugin-2017-03-12";
    src = fetchgit {
      url = "https://github.com/albfan/nerdtree-git-plugin";
      rev = "d79a5d5a1b3bc5fab3ba94db44a8b2e5a211d61d";
      sha256 = "0i77wijbr021zfv096ja15f5l52phvsd5gziqn1m3k60qkmb9gkj";
    };
    dependencies = [];

  };

  vim-closetag = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-closetag-2017-07-24";
    src = fetchgit {
      url = "https://github.com/alvan/vim-closetag";
      rev = "2cacc501df30586c0f96f40f24d1a1239529198c";
      sha256 = "00fayl6bnrf8b80xk73r1009z6hpzfc2jaih042hmnybx8k70byg";
    };
    dependencies = [];

  };

  vim-css-color = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-css-color-2017-02-09";
    src = fetchgit {
      url = "https://github.com/ap/vim-css-color";
      rev = "2411b84298eb6db034001f35ce7cc32c36f9b43b";
      sha256 = "1igqshk7wkh1wgihnmxnlh84fb98fm9lm8lfyjpcz6x8rg5vpmwc";
    };
    dependencies = [];

  };

  clighter8 = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "clighter8-2017-07-23";
    src = fetchgit {
      url = "https://github.com/bbchung/clighter8";
      rev = "a75644681c3a25f9441c482fd0b1c983d12da7e1";
      sha256 = "0hl14l8d0c0rwh7pv1d9bxkrvh1wjxdgjyi7cnhn75m7x9fd3ijh";
    };
    dependencies = [];
    preFixup = ''
      sed "/^let g:clighter8_libclang_path/s|')$|${llvmPackages.clang.cc}/lib/libclang.so')|" \
        -i "$out"/share/vim-plugins/clighter8/plugin/clighter8.vim
    '';
  };

  neomake = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "neomake-2017-07-25";
    src = fetchgit {
      url = "https://github.com/benekastah/neomake";
      rev = "0d1f1508ce2c9cfcffbf74a6bdea9c5766301fd6";
      sha256 = "0wc9b63s4j80f6irf2g6dmk2nx8w9il4dccbgmzirchmymndw4vh";
    };
    dependencies = [];

  };

  vim-hdevtools = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-hdevtools-2017-03-11";
    src = fetchgit {
      url = "https://github.com/bitc/vim-hdevtools";
      rev = "4ffdace7002915cb10d663a2c56386286c5b8e37";
      sha256 = "0s7qd72962sc56j8xzpzikjs9k5s89d5p0j541abl8zm0mavmyka";
    };
    dependencies = [];

  };

  vim-trailing-whitespace = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-trailing-whitespace-2016-03-27";
    src = fetchgit {
      url = "https://github.com/bronson/vim-trailing-whitespace";
      rev = "733fb64337b6da4a51c85a43450cd620d8b617b5";
      sha256 = "1469bd744lf8vk1nnw7kyq4ahpw84crp614mkpq88cs6rhvjhcyw";
    };
    dependencies = [];

  };

  vim-sort-motion = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-sort-motion-2017-04-27";
    src = fetchgit {
      url = "https://github.com/christoomey/vim-sort-motion";
      rev = "9833b22b24b469574178bff4a305472d52bd93b8";
      sha256 = "1rvg4c89vlhqdy0p76rn51hz5mz7qv5pckdacs5zz3g8rcpqxxwq";
    };
    dependencies = [];

  };

  vim-tmux-navigator = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-tmux-navigator-2017-07-07";
    src = fetchgit {
      url = "https://github.com/christoomey/vim-tmux-navigator";
      rev = "d724094e7128acd7375cc758008f1e1688130877";
      sha256 = "1n0n26lx056a0f8nmzbjpf8a48971g4d0fzv8xmq8yy505gbq9iw";
    };
    dependencies = [];

  };

  spacevim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "spacevim-2017-03-31";
    src = fetchgit {
      url = "https://github.com/ctjhoa/spacevim";
      rev = "f4cd52c1746021bb3278c6a085e8d07f1c1a9258";
      sha256 = "0y146z0w1cbqwzw84k479a5hxs1phg1s11fqfvszn8928fsm8c4d";
    };
    dependencies = [];

  };

  ctrlp-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "ctrlp-vim-2017-07-18";
    src = fetchgit {
      url = "https://github.com/ctrlpvim/ctrlp.vim";
      rev = "3a048e85d3c2f72b1564e2dc43ed5b1d67bd59a9";
      sha256 = "10i2lwjizd74b3zi1ahinz2h8qbd18jzw93xrpw0iswrynfsprjv";
    };
    dependencies = [];

  };

  agda-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "agda-vim-2017-07-18";
    src = fetchgit {
      url = "https://github.com/derekelkins/agda-vim";
      rev = "d82c5da78780e866e1afd8eecba1aa9c661c2aa8";
      sha256 = "1aq7wyi1an6znql814w3v30p96yzyd5xnypblzxvsi62jahysfwa";
    };
    dependencies = [];

  };

  vim-scala = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-scala-2017-04-29";
    src = fetchgit {
      url = "https://github.com/derekwyatt/vim-scala";
      rev = "e7640f26e56f0be344d60a6098e05d6928fd396d";
      sha256 = "17gyqzsjjsg48x760qpm31bi169bzq0g80nm88jjkjw75m9jbv2j";
    };
    dependencies = [];

  };

  vim-jade = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-jade-2017-04-07";
    src = fetchgit {
      url = "https://github.com/digitaltoad/vim-jade";
      rev = "ddc5592f8c36bf4bd915c16b38b8c76292c2b975";
      sha256 = "069pha18g1nlzg44k742vjxm4zwjd1qjzhfllkr35qaiflvjm84y";
    };
    dependencies = [];

  };

  pony-vim-syntax = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "pony-vim-syntax-2016-01-23";
    src = fetchgit {
      url = "https://github.com/dleonard0/pony-vim-syntax";
      rev = "a0ab2e14d5a3796ebec01ce196392dc1de349cb3";
      sha256 = "1wraray7870hq75jqxyilxb125flhcgk9ysz437qbg75c495znl0";
    };
    dependencies = [];

  };

  vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-2017-05-24";
    src = fetchgit {
      url = "https://github.com/dracula/vim";
      rev = "6a5bf34193927c70b6c21dcbe1c130d2ab0951d6";
      sha256 = "1mmqrc52k133ddpxcs0mxjph4n4b856r5wbs17bgcpk95cfbspb1";
    };
    dependencies = [];

  };

  neco-ghc = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "neco-ghc-2017-07-22";
    src = fetchgit {
      url = "https://github.com/eagletmt/neco-ghc";
      rev = "1c7bf1b544f295d066863b9f193de709aec5bbad";
      sha256 = "1vbl75s0zvbw6zvs790yla06rl8akpamm0p98s5mbj7mdnivkqhb";
    };
    dependencies = [];

  };

  editorconfig-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "editorconfig-vim-2017-05-13";
    src = fetchgit {
      url = "https://github.com/editorconfig/editorconfig-vim";
      rev = "a069da8426ec5b9fc4d9f83c783c999e9d20f7d0";
      sha256 = "1zx5a8if3r77dnyidix7j0gi04y4pmmi5kfzlr3kjazj00606l79";
    };
    dependencies = [];

  };

  acp = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "acp-2013-02-05";
    src = fetchgit {
      url = "https://github.com/eikenb/acp";
      rev = "5c627cec37d0d3b1670cb250d84e176e8b0c644e";
      sha256 = "0h7s4nvxin7m2caka7g1hhlxj1bbiwsvw8s2lqwlh7nq43v23ghg";
    };
    dependencies = [];

  };

  vim-elixir = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-elixir-2017-07-19";
    src = fetchgit {
      url = "https://github.com/elixir-lang/vim-elixir";
      rev = "7c16ab889d12a32a7d15c54c36c0f47809b06e06";
      sha256 = "0h9gqxqyl6p6ckknn8838wz71xz5v2jqkc2swjdkfbff2n9k1gwb";
    };
    dependencies = [];

  };

  elm-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "elm-vim-2017-07-09";
    src = fetchgit {
      url = "https://github.com/elmcast/elm-vim";
      rev = "ae5315396cd0f3958750f10a5f3ad9d34d33f40d";
      sha256 = "0a85l0mcxgha4s5c9lzdv9y2c1ff942y9a5sfjihz6sph21c77xp";
    };
    dependencies = [];

  };

  vim-localvimrc = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-localvimrc-2017-07-06";
    src = fetchgit {
      url = "https://github.com/embear/vim-localvimrc";
      rev = "48c01c214ea0312e8045aaa1a28b30850e98a194";
      sha256 = "158ajdg3n8j0cxk2ry8rmnpfvnzmznhl573v8ddw6xni58b7bg4d";
    };
    dependencies = [];

  };

  vim-haskellConcealPlus = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-haskellConcealPlus-2016-05-13";
    src = fetchgit {
      url = "https://github.com/enomsg/vim-haskellConcealPlus";
      rev = "81dfb51ff8e471fb1f30659a10daaf1bdd65fb03";
      sha256 = "0vm76gxw62lkyxccrlnn8sblfl3d51svwfra9wfixq4h51jdggyr";
    };
    dependencies = [];

  };

  ensime-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "ensime-vim-2017-07-06";
    src = fetchgit {
      url = "https://github.com/ensime/ensime-vim";
      rev = "a8a2f024283af8e0b69165960ba59d850d1b80a4";
      sha256 = "0vn7iv05jil7j1k4wgnnb9b1b4yqlxjkqmmz8a71291qg17bs5c8";
    };
    dependencies = ["vimproc" "vimshell" "self" "forms"];
    pythonDependencies = with pythonPackages; [ sexpdata websocket_client ];
  };

  YUNOcommit-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "YUNOcommit-vim-2014-11-26";
    src = fetchgit {
      url = "https://github.com/esneider/YUNOcommit.vim";
      rev = "981082055a73ef076d7e27477874d2303153a448";
      sha256 = "0mjc7fn405vcx1n7vadl98p5wgm6jxrlbdbkqgjq8f1m1ir81zab";
    };
    dependencies = [];

  };

  vim-go = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-go-2017-07-25";
    src = fetchgit {
      url = "https://github.com/fatih/vim-go";
      rev = "76cd99db6a88e825f361df0043cbff777c4a14fb";
      sha256 = "1pda9dmaacnzwm92a7vsly053dq2c1bcsqx99rwr41mkpzsk649l";
    };
    dependencies = [];

  };

  vim-colorschemes = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-colorschemes-2016-08-01";
    src = fetchgit {
      url = "https://github.com/flazz/vim-colorschemes";
      rev = "b8dff40f69f1873effbed97c759a8452ecb240ed";
      sha256 = "1mb08l2crl5mal0jllh9s099w2bqcb88vfjw3z5zj1jn8bbpniaj";
    };
    dependencies = [];

  };

  floobits-neovim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "floobits-neovim-2017-07-25";
    src = fetchgit {
      url = "https://github.com/floobits/floobits-neovim";
      rev = "5b83fc75e4241911649782fd5b87ac7da30e77bd";
      sha256 = "05jrybkhg39v3z295l55aasb074wvm3pnyp7l38jqk7z4432gdc4";
    };
    dependencies = [];

  };

  psc-ide-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "psc-ide-vim-2017-07-14";
    src = fetchgit {
      url = "https://github.com/frigoeu/psc-ide-vim";
      rev = "0ff0c0a4e4087cb4444d0a19f2b2e436e723b186";
      sha256 = "0kq8iqhv8flyc12m9ajmbrfk7k6zl3gnnxg5j8sw69aqy6pqvd0p";
    };
    dependencies = [];

  };

  vim-jsonnet = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-jsonnet-2017-04-06";
    src = fetchgit {
      url = "https://github.com/google/vim-jsonnet";
      rev = "2637e273713322befc476760809d46500e6088f3";
      sha256 = "0fxmqasznb3ra49r4j3fmksik7narnd3b6j1j4najp4l61x27ip2";
    };
    dependencies = [];

  };

  vim-jsdoc = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-jsdoc-2017-02-11";
    src = fetchgit {
      url = "https://github.com/heavenshell/vim-jsdoc";
      rev = "cd8f084c3b4bd198620d45a007cee6b009b57b35";
      sha256 = "0a2d9jwxjws8l7y89yn7xl07r5yh7r7987a8hfalvz12qmdmff1j";
    };
    dependencies = [];

  };

  vim-leader-guide = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-leader-guide-2017-03-18";
    src = fetchgit {
      url = "https://github.com/hecal3/vim-leader-guide";
      rev = "6ac8c663e65c9c0ded70417b84f66ee59457893e";
      sha256 = "1hqha3ig40ls15bnb10xpbl91swn0gxqnhmz5frkvvdzj4wq55fw";
    };
    dependencies = [];

  };

  idris-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "idris-vim-2017-06-05";
    src = fetchgit {
      url = "https://github.com/idris-hackers/idris-vim";
      rev = "0709927e689f4f4158661d4eb8ac6ce310cd7548";
      sha256 = "05fiamb92l7d08kxv1jk5xpqvkxphr9vqi3bfa203mjkvymd3x34";
    };
    dependencies = [];

  };

  calendar-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "calendar-vim-2017-07-08";
    src = fetchgit {
      url = "https://github.com/itchyny/calendar.vim";
      rev = "6d6be26b2ad1870658525e2a42046429c845516c";
      sha256 = "0g4k7vn3r8y0ss0nl6apxgpkdi7ixi87a9g5xr66n70lxyn7m9pz";
    };
    dependencies = [];

  };

  lightline-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "lightline-vim-2017-05-30";
    src = fetchgit {
      url = "https://github.com/itchyny/lightline.vim";
      rev = "ff74d6561487d220ed9d878172d8b55a79a4c17e";
      sha256 = "0j8pn42vfc1ka6hjnfsanl98vlk2839am5d4ynz9p1j1hichiqzv";
    };
    dependencies = [];

  };

  thumbnail-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "thumbnail-vim-2017-04-24";
    src = fetchgit {
      url = "https://github.com/itchyny/thumbnail.vim";
      rev = "71cb5d48e59fc77149c1d1036ecd9e39f0b46a00";
      sha256 = "0b25n28ri6n5rrvgfynv8rm5pzzxpnrnj1l3647pf2fjxd2z2rv5";
    };
    dependencies = [];

  };

  vim-ipython = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-ipython-2015-06-23";
    src = fetchgit {
      url = "https://github.com/ivanov/vim-ipython";
      rev = "42499f094b805b90b683afa5009cee99abd0bb75";
      sha256 = "10wpfvfs8yv1bvzra4d5zy5glp62gbalpayxx7mkalhr2ccppy3x";
    };
    dependencies = [];

  };

  vim-hier = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-hier-2011-08-27";
    src = fetchgit {
      url = "https://github.com/jceb/vim-hier";
      rev = "0b8c365263551a67404ebd7e528c55e17c1d3de7";
      sha256 = "118pd9sx1bl9vfr89xrf536hfx4l162a43a1qpwpkqxzb9a3ca7n";
    };
    dependencies = [];
    buildInputs = [ vim ];
  };

  vim-orgmode = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-orgmode-2017-04-19";
    src = fetchgit {
      url = "https://github.com/jceb/vim-orgmode";
      rev = "8a5cb51fbb8d89b0151833a6deb654929818a964";
      sha256 = "0siqzwblads3n69chqsifpgglcda2iz2k40q76llf78fw5ylqd16";
    };
    dependencies = [];

  };

  vim-buffergator = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-buffergator-2017-02-05";
    src = fetchgit {
      url = "https://github.com/jeetsukumaran/vim-buffergator";
      rev = "04dfbc0c78b0a29b340a99d0ff36ecf8f16e017d";
      sha256 = "1z13qqmvzismz7f6ss2pk956adnqh14df8qrlzk9rgplknm4w6k7";
    };
    dependencies = [];

  };

  tslime-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "tslime-vim-2016-06-14";
    src = fetchgit {
      url = "https://github.com/jgdavey/tslime.vim";
      rev = "c980c76bbfc9a523fcf1edf08580d0d3a486e8f2";
      sha256 = "0gifyxwlspfnkni886adwn9kc0dckanjk0097y8pwxh7qbwfydf1";
    };
    dependencies = [];

  };

  auto-pairs = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "auto-pairs-2017-07-03";
    src = fetchgit {
      url = "https://github.com/jiangmiao/auto-pairs";
      rev = "f0019fc6423e7ce7bbd01d196a7e027077687fda";
      sha256 = "1kzrdq3adwxwm3fw65g05ww9405lwqi368win5kayamyj9i0z7r6";
    };
    dependencies = [];

  };

  vim-nerdtree-tabs = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-nerdtree-tabs-2017-07-04";
    src = fetchgit {
      url = "https://github.com/jistr/vim-nerdtree-tabs";
      rev = "47bbe5afc26f701f08d31b2bbdb660f117367ded";
      sha256 = "0a1gqdvmpa4gylnb7sxs6zr89i60fl16p477200x18hgh2zd2v02";
    };
    dependencies = [];

  };

  zenburn = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "zenburn-2015-09-18";
    src = fetchgit {
      url = "https://github.com/jnurmine/zenburn";
      rev = "f7847fb1531b91e2b4bb4aed5db3146f07765179";
      sha256 = "1las12jznf25dkxrjk3s9l70c6wnpjisngmvi83bhw5gvx4c7mq5";
    };
    dependencies = [];

  };

  vim-colorstepper = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-colorstepper-2016-01-28";
    src = fetchgit {
      url = "https://github.com/jonbri/vim-colorstepper";
      rev = "f23ba0d995d41508a2dc9471cf31d3d01a4b5f05";
      sha256 = "05ykxn0gmh8liz0zv5hb8df1ajggxp88izq3825m0yb3ma3k1jqs";
    };
    dependencies = [];

  };

  vim-xdebug = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-xdebug-2012-08-15";
    src = fetchgit {
      url = "https://github.com/joonty/vim-xdebug";
      rev = "a4980fa65f7f159780593ee37c178281691ba2c4";
      sha256 = "1qh18r0sm4gh95sjbi2hnflvxdl4gk00jyy3n7z4i1gnx9ihxjqw";
    };
    dependencies = [];
    postInstall = false;
  };

  fzf-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "fzf-vim-2017-07-24";
    src = fetchgit {
      url = "https://github.com/junegunn/fzf.vim";
      rev = "685f9aae97072a190a1230a5c79692e15b7f46c9";
      sha256 = "1064qwypq8hl0dx65fhvx0aq4jp7hc60rzb0vy98zjr3sr4wshbh";
    };
    dependencies = [];

  };

  limelight-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "limelight-vim-2016-06-24";
    src = fetchgit {
      url = "https://github.com/junegunn/limelight.vim";
      rev = "106fb5749d227a0de72e36068ed72798c6fd48e6";
      sha256 = "0fp4yp50n5v5zx3a7afh9wip4nwcfhmdgdzwpnl79jvild1z9fgh";
    };
    dependencies = [];

  };

  vim-peekaboo = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-peekaboo-2017-03-20";
    src = fetchgit {
      url = "https://github.com/junegunn/vim-peekaboo";
      rev = "a7c940b15b008afdcea096d3fc4d25e3e431eb49";
      sha256 = "1rc4hr6vwj2mmrgz8lifxf9rvcw1rb5dahq649yn8ccw03x8zn6m";
    };
    dependencies = [];

  };

  vim-eighties = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-eighties-2016-12-15";
    src = fetchgit {
      url = "https://github.com/justincampbell/vim-eighties";
      rev = "1a6ea42ead1e31524ec94cfefb6afc1d8dacd170";
      sha256 = "1yh1kny28c7f5qm52y7xd5aj4mycksfb0x1zvcb37c73ycdxc1v2";
    };
    dependencies = [];

  };

  latex-box = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "latex-box-2015-06-01";
    src = fetchgit {
      url = "https://github.com/latex-box-team/latex-box";
      rev = "3c2901e12cb78bfb2be58ba4c62a488612550fe1";
      sha256 = "1z4mdy47cpwcdhvy8mr72vhlybxn1y59yd3ixf6ids1bzpkrd7zl";
    };
    dependencies = [];

  };

  typescript-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "typescript-vim-2017-03-15";
    src = fetchgit {
      url = "https://github.com/leafgarland/typescript-vim";
      rev = "4dc79bd1b0c43c16cae146bee065f2acc6d2b789";
      sha256 = "1hm7cpkx7na106xpivzi5cqb322nanpa0sdjmvnkhgll244q5vy4";
    };
    dependencies = [];

  };

  vim-jinja = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-jinja-2016-11-16";
    src = fetchgit {
      url = "https://github.com/lepture/vim-jinja";
      rev = "8d330a7aaf0763d080dc82204b4aaba6ac0605c6";
      sha256 = "1n62ga02rcj7jjgzvwr46pckj59dc1zqahjgampjcwdd8vf4mg3q";
    };
    dependencies = [];

  };

  vimtex = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vimtex-2017-07-25";
    src = fetchgit {
      url = "https://github.com/lervag/vimtex";
      rev = "1bba731f008a0905c1cf34e185c3f299d1f1759b";
      sha256 = "0gcsfdc2rrdaylsqz6hn9smchndb4y22f4sm230ljdf1rda6v57v";
    };
    dependencies = [];

  };

  vim-easymotion = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-easymotion-2017-07-14";
    src = fetchgit {
      url = "https://github.com/lokaltog/vim-easymotion";
      rev = "e4d71c7ba45baf860fdaaf8c06cd9faebdccbd50";
      sha256 = "16ww4myvgh7is5fbwm67v87bbdyhldvr9d4vqkvnn8v9mbj7p7vd";
    };
    dependencies = [];

  };

  vim-lawrencium = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-lawrencium-2017-01-10";
    src = fetchgit {
      url = "https://github.com/ludovicchabant/vim-lawrencium";
      rev = "88077183e1f5a9a1f741aeab7a1374cfed9e917f";
      sha256 = "0z31v93wjycq4lqvbl1jzxi7i5i1vl919m4dyyzphybcqrjjpnab";
    };
    dependencies = [];

  };

  rainbow = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "rainbow-2017-04-21";
    src = fetchgit {
      url = "https://github.com/luochen1990/rainbow";
      rev = "1c45e0f81324641b23d4c21edda4eabeacba031b";
      sha256 = "143bkawg4sy1vbizfwb6p9alizyr80sr6incxrz179l9dp9r8frf";
    };
    dependencies = [];

  };

  vim-xkbswitch = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-xkbswitch-2017-03-27";
    src = fetchgit {
      url = "https://github.com/lyokha/vim-xkbswitch";
      rev = "a85ebddb9038e6b05138c48868a319a9e13d1868";
      sha256 = "0v0wckkvsj3pd3a5lj35dqwlvgr1kfz0x6rpnx28mzrcg05p19fr";
    };
    dependencies = [];
    patchPhase = ''
      substituteInPlace plugin/xkbswitch.vim \
              --replace /usr/local/lib/libxkbswitch.so ${xkb_switch}/lib/libxkbswitch.so
    '';
    buildInputs = [ xkb_switch ];
  };

  vim-highlightedyank = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-highlightedyank-2017-03-25";
    src = fetchgit {
      url = "https://github.com/machakann/vim-highlightedyank";
      rev = "d656e1e62d2b4e1abd66c5f3a13a2be31a5a80ed";
      sha256 = "0rcd2q8f49iyv93s5g95brml7sng7lr8k9s5m4mxq3y0m9yf68fd";
    };
    dependencies = [];

  };

  Jenkinsfile-vim-syntax = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Jenkinsfile-vim-syntax-2017-05-16";
    src = fetchgit {
      url = "https://github.com/martinda/Jenkinsfile-vim-syntax";
      rev = "d3ad4bc4888740c524bfa2f8b3192cfb23ddec3f";
      sha256 = "1sw1rwxspa94aak9gq6i1z47cqhkm2nbbj8xlkzbk3c04mqljksf";
    };
    dependencies = [];

  };

  forms = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "forms-2012-11-28";
    src = fetchgit {
      url = "https://github.com/megaannum/forms";
      rev = "b601e03fe0a3b8a43766231f4a6217e4492b4f75";
      sha256 = "19kp1i5c6jmnpbsap9giayqbzlv7vh02mp4mjvicqj9n0nfyay74";
    };
    dependencies = ["self"];

  };

  self = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "self-2014-05-28";
    src = fetchgit {
      url = "https://github.com/megaannum/self";
      rev = "2ed666b547eddee6ae1fcc63babca4ba0b66a59f";
      sha256 = "1gcwn6i5i3msg7hrlzsnv1bs6pm4jz9cff8ppaz2xdj8xv9qy6fn";
    };
    dependencies = [];

  };

  vim-startify = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-startify-2017-06-15";
    src = fetchgit {
      url = "https://github.com/mhinz/vim-startify";
      rev = "7f910ed4367de96310fedc98d5a12b97173a405f";
      sha256 = "1l5q8mqqp6gzmxqm5i0lx6lbm181vmkcg8w24ypa77vnid0ihd93";
    };
    dependencies = [];

  };

  vim-indent-object = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-indent-object-2017-03-23";
    src = fetchgit {
      url = "https://github.com/michaeljsmith/vim-indent-object";
      rev = "41d700f14b3decccdde421fbfe49e95a084a2f89";
      sha256 = "12mi4n5abfxx7xjl46aw400acgrjf1fxjgzak763l874y0whf5v2";
    };
    dependencies = [];

  };

  ack-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "ack-vim-2017-05-07";
    src = fetchgit {
      url = "https://github.com/mileszs/ack.vim";
      rev = "a16a9b63eb85cc0960a7f25c54647ac1f99f3360";
      sha256 = "09bwawm2csliancl281y6wgalrrmaqq7d0baz4dq1cw18x657mk7";
    };
    dependencies = [];

  };

  vim-yapf = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-yapf-2017-03-21";
    src = fetchgit {
      url = "https://github.com/mindriot101/vim-yapf";
      rev = "324380d77c9cf8e46e22b2e4391702273a53f563";
      sha256 = "0vsd53k5k8absc60qka8nlj2ij6k4zgff2a65ixc7vqcmawxr3nw";
    };
    dependencies = [];
    buildPhase = ''
      substituteInPlace ftplugin/python_yapf.vim \
        --replace '"yapf"' '"${pythonPackages.yapf}/bin/yapf"'
    '';
  };

  lushtags = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "lushtags-2017-04-19";
    src = fetchgit {
      url = "https://github.com/mkasa/lushtags";
      rev = "fd7fa5a0162d9aa159559880d5ba4731e180eeaf";
      sha256 = "1si5n07k4r8kji4whglav9q59ksv6bi5v58xbpc2l5bavlk8kn6n";
    };
    dependencies = [];

  };

  hlint-refactor-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "hlint-refactor-vim-2015-12-05";
    src = fetchgit {
      url = "https://github.com/mpickering/hlint-refactor-vim";
      rev = "fffb044ecef854a82c5c2efda252e09044ba03e0";
      sha256 = "0z8d31arfy9aidg1dwj5msnnx799d9r7njkgh51z695w6ayxn6p8";
    };
    dependencies = [];

  };

  vim-indent-guides = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-indent-guides-2017-07-03";
    src = fetchgit {
      url = "https://github.com/nathanaelkane/vim-indent-guides";
      rev = "b40687195c01caf40f62d20093296590b48e3a75";
      sha256 = "17hc3bdb707lkg0kyac2czjjijdrzarnh6sr78s9rqpwrj3fj4i4";
    };
    dependencies = [];

  };

  vim-stylish-haskell = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-stylish-haskell-2015-05-10";
    src = fetchgit {
      url = "https://github.com/nbouscal/vim-stylish-haskell";
      rev = "c664376ba814de3f87cb7641f90b2c6a9dd53671";
      sha256 = "1xm5ark2mwphznv3xsyzgcldnr52i5jzk1pfqdh0080j07aama8j";
    };
    dependencies = [];

  };

  haskell-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "haskell-vim-2017-07-18";
    src = fetchgit {
      url = "https://github.com/neovimhaskell/haskell-vim";
      rev = "21c48768f1c5986d4f2351784b119eb9a5f925db";
      sha256 = "1dd18plhahkdz782d7y8w8265di2wvs78w2q2hx2m68686abmn0h";
    };
    dependencies = [];

  };

  cpsm = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "cpsm-2017-02-12";
    src = fetchgit {
      url = "https://github.com/nixprime/cpsm";
      rev = "8e61bf3e30868c57ad7cf1fe4315b2352d61467c";
      sha256 = "0qcc10dx48wyvcgz9q3nid9l1wxvl9m97608s289lj4zps8iqpcs";
    };
    dependencies = [];
    buildInputs = [
      python3
      stdenv
      cmake
      boost
      icu
    ];
    buildPhase = ''
      patchShebangs .
      export PY3=ON
      ./install.sh
    '';
  };

  shabadou-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "shabadou-vim-2016-07-19";
    src = fetchgit {
      url = "https://github.com/osyo-manga/shabadou.vim";
      rev = "7d4bfed1ea8985ae125df3d1403cc19e252443e1";
      sha256 = "1kvik1yf7yjg9jdmdw38yhkksxg0n3nry02banwik7wgjnpvg870";
    };
    dependencies = [];

  };

  vim-watchdogs = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-watchdogs-2017-06-23";
    src = fetchgit {
      url = "https://github.com/osyo-manga/vim-watchdogs";
      rev = "22a08dcd33223ddbe95c977ca72e77d62d2c75d9";
      sha256 = "0d3i39cz5kpps2gxlbz2l73bz0rs67lhh6qrpzl3a2p014hixbyi";
    };
    dependencies = [];

  };

  vim-markdown = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-markdown-2017-05-10";
    src = fetchgit {
      url = "https://github.com/plasticboy/vim-markdown";
      rev = "3fcde7215e22913f004c2836fd46ff61746be6db";
      sha256 = "0ymbs7235zi5hwyzc0vaikb3n6jwj6xarmgjj4lpf4wbsa1212yy";
    };
    dependencies = [];

  };

  python-mode = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "python-mode-2017-07-04";
    src = fetchgit {
      url = "https://github.com/python-mode/python-mode";
      rev = "d2dead6ce9d900b26dbf1a06c52969f4194eda64";
      sha256 = "1iq26a2l9maapz3433pwywmqla4wf7jass7s7bh32h10m2fh88a0";
    };
    dependencies = [];

  };

  vim-racer = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-racer-2017-07-19";
    src = fetchgit {
      url = "https://github.com/racer-rust/vim-racer";
      rev = "c729b895885c9ef548ed4f9c1cec7c7c741b5869";
      sha256 = "1r0idhc7yj5r4h2rfmbb5p0i1yckr3mckif3ijy6sm9rhwi242sw";
    };
    dependencies = [];

  };

  purescript-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "purescript-vim-2016-08-31";
    src = fetchgit {
      url = "https://github.com/raichoo/purescript-vim";
      rev = "2c55bcefd63bc40ed2aa9d6ce9d89a590dfa3477";
      sha256 = "1y96w8p865gd6zr29wpxn1qwsk833y06x1qp586gylgi0jp1ybzv";
    };
    dependencies = [];

  };

  vim-grammarous = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-grammarous-2017-07-02";
    src = fetchgit {
      url = "https://github.com/rhysd/vim-grammarous";
      rev = "d117cd139b58319d8ac94f2fd36ee548b6ea1e88";
      sha256 = "0a5a65j9a3s54z9asjmfbqsvawx014bq772jqgpsxww53lap3s5x";
    };
    dependencies = [];

  };

  vim-puppet = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-puppet-2017-07-02";
    src = fetchgit {
      url = "https://github.com/rodjek/vim-puppet";
      rev = "cb1863af2ba4de9fb1c1d952d82692502348fb92";
      sha256 = "0a3q6f8jplxbvpjaz9vnh589al64vg567nc00xabp46vcm83nk4x";
    };
    dependencies = [];

  };

  rust-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "rust-vim-2017-07-14";
    src = fetchgit {
      url = "https://github.com/rust-lang/rust.vim";
      rev = "5a6133680ecf9e22eeba35c35e62ea6210225b02";
      sha256 = "0mxzl8lghq7bnwp8qs3haxq83ds5q8s8br0ajn40a3c3ns2hkhla";
    };
    dependencies = [];

  };

  neoformat = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "neoformat-2017-07-22";
    src = fetchgit {
      url = "https://github.com/sbdchd/neoformat";
      rev = "a0c8e1f3c8b917afd175fc9ed9b2685ce5f952e9";
      sha256 = "1w2m54ag1g1czfwa8y2vq4p05wysvb1qhgfnbzqvlwb1mn9sh2kf";
    };
    dependencies = [];

  };

  deoplete-rust = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "deoplete-rust-2017-07-18";
    src = fetchgit {
      url = "https://github.com/sebastianmarkow/deoplete-rust";
      rev = "0a86e502113910c33448b337c4d50cabea120d25";
      sha256 = "0wsck83jns40ny3740vwjhc8g5bh6zl71hkirbjxy6n4xgixa54h";
    };
    dependencies = [];

  };

  vim-polyglot = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-polyglot-2017-06-12";
    src = fetchgit {
      url = "https://github.com/sheerun/vim-polyglot";
      rev = "8eab5f5403afc1c33a7593459a27f7ff625fa60b";
      sha256 = "0q2xfmqk5iad6gv8zzlpcv48xpv7lwr6mswc7mdllzkgaqilz75g";
    };
    dependencies = [];

  };

  neco-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "neco-vim-2017-07-23";
    src = fetchgit {
      url = "https://github.com/shougo/neco-vim";
      rev = "7c188577ebf65bfb9e27affce8158e0f5af2ec3e";
      sha256 = "1jb9vw2gkag2fg18vxqj3rc6y4zqgrn0kf6vb5z8kgkbsam0cybk";
    };
    dependencies = [];

  };

  neocomplete-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "neocomplete-vim-2017-07-23";
    src = fetchgit {
      url = "https://github.com/shougo/neocomplete.vim";
      rev = "d8caad4fc14fc1be5272bf6ebc12048212d67d2c";
      sha256 = "1ab1p4w6187r15alb34mnvaq43mikk7ic05ysgilx4f4zz6dgz5y";
    };
    dependencies = [];

  };

  neosnippet-snippets = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "neosnippet-snippets-2017-07-05";
    src = fetchgit {
      url = "https://github.com/shougo/neosnippet-snippets";
      rev = "b89c544264912b064c79da2a90fc5d4e69d621b2";
      sha256 = "1cqgagzxl559mf06kkggdm90g27is0x80qqrrha09ng16hf6qf7a";
    };
    dependencies = [];

  };

  neosnippet-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "neosnippet-vim-2017-07-15";
    src = fetchgit {
      url = "https://github.com/shougo/neosnippet.vim";
      rev = "4bf88a9e497dc7180e9fe58551ad340de0192f39";
      sha256 = "0mj14cninszfw95zb0rwcmzf40851i49lj6vk8gz4iq9y0hxsnx7";
    };
    dependencies = [];

  };

  unite-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "unite-vim-2017-07-01";
    src = fetchgit {
      url = "https://github.com/shougo/unite.vim";
      rev = "ad15f96365b5cb43a45d0ca779df6a497f954f15";
      sha256 = "0pigwfwyas4zdzrazk08p9bnbmi51np4gb0mf5dy434glw9rrvjz";
    };
    dependencies = [];

  };

  vimproc-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vimproc-vim-2017-07-22";
    src = fetchgit {
      url = "https://github.com/shougo/vimproc.vim";
      rev = "03a38f283ca9e15784e8fea84e8afc5d633b9639";
      sha256 = "0ypffp724f3qp0mryxmmmi1ci0bnz34nnr7yi3c893pd9mpkrjjr";
    };
    dependencies = [];
    buildInputs = [ which ];

    buildPhase = ''
      substituteInPlace autoload/vimproc.vim \
        --replace vimproc_mac.so vimproc_unix.so \
        --replace vimproc_linux64.so vimproc_unix.so \
        --replace vimproc_linux32.so vimproc_unix.so
      make -f make_unix.mak
    '';
  };

  vimshell-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vimshell-vim-2016-12-14";
    src = fetchgit {
      url = "https://github.com/shougo/vimshell.vim";
      rev = "d0c5bef010237855b4de25863bc54895effe5d7a";
      sha256 = "13szswi1n04w66c4h701y47xblrba8ysxjwvmnfxb0pyd1x3gzgz";
    };
    dependencies = [ "vimproc-vim" ];
  };

  gundo-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "gundo-vim-2017-05-09";
    src = fetchgit {
      url = "https://github.com/sjl/gundo.vim";
      rev = "46c443ee9d5854320eb965a1fdee781ba83a070e";
      sha256 = "0adk7agzmbfv342zw6lc8jad6yjs1wap4c0ca98s0qm2bs0r1hl2";
    };
    dependencies = [];

  };

  alchemist-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "alchemist-vim-2017-07-23";
    src = fetchgit {
      url = "https://github.com/slashmili/alchemist.vim";
      rev = "35b0e59b4ae45baeef7fc46b6faf9b96515d35cb";
      sha256 = "021iwhnjjsfhmpbimm91jgmcrlj1hjh8rxcdqxwcwxc92h73wl58";
    };
    dependencies = [];

  };

  vim-hardtime = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-hardtime-2017-03-31";
    src = fetchgit {
      url = "https://github.com/takac/vim-hardtime";
      rev = "d9128568afa62947b7ac8f12c22d88e3de526a6b";
      sha256 = "097wzfh4n4fnsq2gx4hbmyr731ciky8qcai5aiyh2baybvwshmr5";
    };
    dependencies = [];

  };

  vim-expand-region = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-expand-region-2013-08-19";
    src = fetchgit {
      url = "https://github.com/terryma/vim-expand-region";
      rev = "966513543de0ddc2d673b5528a056269e7917276";
      sha256 = "0l30wjlk4vxr16f1njnvf8aw9yg9p9jisvcxbcg3znsq5q8ix6zv";
    };
    dependencies = [];

  };

  vimpreviewpandoc = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vimpreviewpandoc-2016-03-07";
    src = fetchgit {
      url = "https://github.com/tex/vimpreviewpandoc";
      rev = "b109d41ad6478df5ec7f1311950c6efca66f36e4";
      sha256 = "1gx326xarjs3qjygpkrknncad90crjqfx8v6pir4r7k1hl7dfxc4";
    };
    dependencies = [];

  };

  vim-quickrun = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-quickrun-2017-03-21";
    src = fetchgit {
      url = "https://github.com/thinca/vim-quickrun";
      rev = "98889e1fc0f7136262c4dd7c312b82879df16486";
      sha256 = "1drv53fwp24z0yb79lj2nyapyndw1yirg202hg7px9jvxjr4k8a0";
    };
    dependencies = [];

  };

  molokai = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "molokai-2015-11-11";
    src = fetchgit {
      url = "https://github.com/tomasr/molokai";
      rev = "c67bdfcdb31415aa0ade7f8c003261700a885476";
      sha256 = "1piszjr5kyw43ac1f0jh9z88g824xknshrkchbys9qxlz7pd831s";
    };
    dependencies = [];

  };

  vim-dispatch = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-dispatch-2017-07-12";
    src = fetchgit {
      url = "https://github.com/tpope/vim-dispatch";
      rev = "14a1695f844a320dd28a7706710325773d1046a8";
      sha256 = "1whmqikg5ch523ffs2apkrd4clwl7s0y98gmxgaqq6gm2fa2wmfp";
    };
    dependencies = [];

  };

  vim-eunuch = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-eunuch-2017-06-08";
    src = fetchgit {
      url = "https://github.com/tpope/vim-eunuch";
      rev = "b536b887072ff3cc382842ce9f675ec222302f4f";
      sha256 = "0vp037kb12mawy186cm384m5hl0p051rihhm1jr2qck0vwaps58p";
    };
    dependencies = [];

  };

  vim-repeat = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-repeat-2017-04-21";
    src = fetchgit {
      url = "https://github.com/tpope/vim-repeat";
      rev = "070ee903245999b2b79f7386631ffd29ce9b8e9f";
      sha256 = "1grsaaar2ng1049gc3r8wbbp5imp31z1lcg399vhh3k36y34q213";
    };
    dependencies = [];

  };

  vim-speeddating = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-speeddating-2017-05-24";
    src = fetchgit {
      url = "https://github.com/tpope/vim-speeddating";
      rev = "a418667791f03694065948342f2d6c5cca8d0f32";
      sha256 = "1wm33izawazh0dy70zjk6rkg30yrlldba5r1gypnr4barps702gw";
    };
    dependencies = [];

  };

  hasksyn = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "hasksyn-2014-09-03";
    src = fetchgit {
      url = "https://github.com/travitch/hasksyn";
      rev = "c434040bf13a17ca20a551223021b3ace7e453b9";
      sha256 = "09998lnfcshqis5m062wlag6y476imq9jday9gp4ayjjl1cp3cwx";
    };
    dependencies = [];

  };

  vim-haskellconceal = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-haskellconceal-2017-06-15";
    src = fetchgit {
      url = "https://github.com/twinside/vim-haskellconceal";
      rev = "802f82a5afee56e9e1251e6f756104a3bd114234";
      sha256 = "1kh6853hi4rgl4z1xs8kz9l1q9w7lh0r42y2m0rabfpr6yh3091r";
    };
    dependencies = [];

  };

  youcompleteme = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "youcompleteme-2017-07-24";
    src = fetchgit {
      url = "https://github.com/valloric/youcompleteme";
      rev = "998303e2fd5e762c3bc2aee8c23af1b388fb459c";
      sha256 = "158wnxgnjir4n5p1jnpxqq4qwl6hapd9kpdd3gklihxvbj1zqskc";
    };
    dependencies = [];
    buildPhase = ''
      substituteInPlace plugin/youcompleteme.vim \
        --replace "'ycm_path_to_python_interpreter', '''" \
                  "'ycm_path_to_python_interpreter', '${python}/bin/python'"

      rm -r third_party/ycmd
      ln -s ${ycmd}/lib/ycmd third_party
    '';

    meta = {
      description = "Fastest non utf-8 aware word and C completion engine for Vim";
      homepage = http://github.com/Valloric/YouCompleteMe;
      license = stdenv.lib.licenses.gpl3;
      maintainers = with stdenv.lib.maintainers; [marcweber jagajaga];
      platforms = stdenv.lib.platforms.unix;
    };
  };

  vim-airline-themes = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-airline-themes-2017-07-10";
    src = fetchgit {
      url = "https://github.com/vim-airline/vim-airline-themes";
      rev = "5d75d76ca2e17edd68f89ac4f547009d477570c6";
      sha256 = "15vq8fjax69wi447vhirj7vzqxppxcpvq2v8dhi0pf39gbzcd229";
    };
    dependencies = [];

  };

  vim-pandoc = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-pandoc-2017-04-26";
    src = fetchgit {
      url = "https://github.com/vim-pandoc/vim-pandoc";
      rev = "fc209c66e937172efdd6db39ee64fcb3980ce329";
      sha256 = "19x8hf78833hcg508sn5a4g79h47ynqzzas998rqr2cmmpsc4mzs";
    };
    dependencies = [];

  };

  vim-pandoc-after = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-pandoc-after-2015-06-01";
    src = fetchgit {
      url = "https://github.com/vim-pandoc/vim-pandoc-after";
      rev = "4377665e5c98f29ea838deb3b942200b8dd096ef";
      sha256 = "1379g174pvsaw1wdv1n18gby84sv59rsamfcgq9bqd4kg54g6h3j";
    };
    dependencies = [];

  };

  vim-pandoc-syntax = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-pandoc-syntax-2017-04-13";
    src = fetchgit {
      url = "https://github.com/vim-pandoc/vim-pandoc-syntax";
      rev = "56e8e41ef863a0a7d33d85c3c0c895aa6e9e62d3";
      sha256 = "19ll4zrw5yd0frgsbi7pg9b68lmy4bfiwbnwgzii7inifrqsykfw";
    };
    dependencies = [];

  };

  Colour-Sampler-Pack = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Colour-Sampler-Pack-2012-11-29";
    src = fetchgit {
      url = "https://github.com/vim-scripts/Colour-Sampler-Pack";
      rev = "05cded87b2ef29aaa9e930230bb88e23abff4441";
      sha256 = "03v2r18sfgs0xbgy9p56pxfdg0lsk6m7wyr5hw63wm1nzpwiipg3";
    };
    dependencies = [];

  };

  Rename = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Rename-2011-08-30";
    src = fetchgit {
      url = "https://github.com/vim-scripts/Rename";
      rev = "b240f28d2ede65fa77cd99fe045efe79202f7a34";
      sha256 = "1d1myg4zyc281zcc1ba9idbgcgxndb4a0jwqr4yqxhhzdgszw46r";
    };
    dependencies = [];

  };

  ReplaceWithRegister = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "ReplaceWithRegister-2014-10-30";
    src = fetchgit {
      url = "https://github.com/vim-scripts/ReplaceWithRegister";
      rev = "832efc23111d19591d495dc72286de2fb0b09345";
      sha256 = "0mb0sx85j1k59b1zz95r4vkq4kxlb4krhncq70mq7fxrs5bnhq8g";
    };
    dependencies = [];

  };

  a-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "a-vim-2010-11-06";
    src = fetchgit {
      url = "https://github.com/vim-scripts/a.vim";
      rev = "2cbe946206ec622d9d8cf2c99317f204c4d41885";
      sha256 = "0h62v9z5bh9xmaq22pqdb3z79i84a5rknqm68mjpy7nq7s3q42fa";
    };
    dependencies = [];

  };

  align = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "align-2012-08-07";
    src = fetchgit {
      url = "https://github.com/vim-scripts/align";
      rev = "787662fe90cd057942bc5b682fd70c87e1a9dd77";
      sha256 = "0acacr572kfh7jvavbw61q5pkwrpi1albgancma063rpax1pddgp";
    };
    dependencies = [];

  };

  argtextobj-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "argtextobj-vim-2010-10-17";
    src = fetchgit {
      url = "https://github.com/vim-scripts/argtextobj.vim";
      rev = "f3fbe427f7b4ec436416a5816d714dc917dc530b";
      sha256 = "1l4jh5hdmky1qj5z26jpnk49a6djjcvzyyr6pknrrgb8rzkiln48";
    };
    dependencies = [];

  };

  changeColorScheme-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "changeColorScheme-vim-2010-10-17";
    src = fetchgit {
      url = "https://github.com/vim-scripts/changeColorScheme.vim";
      rev = "b041d49f828629d72f2232531a230d1ec5de2405";
      sha256 = "0pybhsg9k9252d4ifdc4gsar8lkmfzbvs6xkzqq1m6f35l9wqk09";
    };
    dependencies = [];

  };

  random-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "random-vim-2010-10-17";
    src = fetchgit {
      url = "https://github.com/vim-scripts/random.vim";
      rev = "b2d85eb24a38074eab37a5acf2a295e1f2ad8989";
      sha256 = "1lzy2cq4jcrsqyxlnbnd0y6j4mabm09bi7q22lf6vinqlb84w7sp";
    };
    dependencies = [];

  };

  tabmerge = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "tabmerge-2010-10-17";
    src = fetchgit {
      url = "https://github.com/vim-scripts/tabmerge";
      rev = "074e5f06f26e7108a0570071a0f938a821768c06";
      sha256 = "0prkyza1n49cdaslcr57w8zv15vw78mlqbzib2xipmawzjq02idq";
    };
    dependencies = [];

  };

  wombat256-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "wombat256-vim-2010-10-17";
    src = fetchgit {
      url = "https://github.com/vim-scripts/wombat256.vim";
      rev = "8734ba45dcf5e38c4d2686b35c94f9fcb30427e2";
      sha256 = "01fdvfwdfqn5xi88lfanb4lb6jmn1ma6wq6d9jj2x7qamdbpvsrg";
    };
    dependencies = [];

  };

  ale = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "ale-2017-07-23";
    src = fetchgit {
      url = "https://github.com/w0rp/ale";
      rev = "a0059cfe0362e8ba55bad1f4fa8a310c74b55280";
      sha256 = "0hjli8ww0i4yxa7gxiyvy9xgc9s8krr7vhdh8036nwwnrzrmcc5h";
    };
    dependencies = [];

  };

  vim-wakatime = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-wakatime-2017-07-03";
    src = fetchgit {
      url = "https://github.com/wakatime/vim-wakatime";
      rev = "0c5368cf01f4d452a05eb5e5569e6fe78dca2657";
      sha256 = "025d0gz0fs3jb062jp7js11b8vb20zyxa32llqsjkyy4gr8kv53b";
    };
    dependencies = [];
    buildInputs = [ python ];
  };

  command-t = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "command-t-2017-06-23";
    src = fetchgit {
      url = "https://github.com/wincent/command-t";
      rev = "29f2606a9665058a98b56f2d8062ba614a3f246e";
      sha256 = "0q6kqjy88w1478k2q6vqyyid69whd72746i0cd33xnslgykwm2hn";
    };
    dependencies = [];
    buildInputs = [ perl ruby git ];
    buildPhase = ''
      pushd ruby/command-t
      gem build ./command-t.gemspec
      popd
    '';
  };

  vim-easytags = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-easytags-2015-07-01";
    src = fetchgit {
      url = "https://github.com/xolox/vim-easytags";
      rev = "72a8753b5d0a951e547c51b13633f680a95b5483";
      sha256 = "0i8ha1fa5d860b1mi0xp8kwsgb0b9vbzcg1bldzv6s5xd9yyi12i";
    };
    dependencies = ["vim-misc"];

  };

  vim-misc = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-misc-2015-05-21";
    src = fetchgit {
      url = "https://github.com/xolox/vim-misc";
      rev = "3e6b8fb6f03f13434543ce1f5d24f6a5d3f34f0b";
      sha256 = "0rd9788dyfc58py50xbiaz5j7nphyvf3rpp3yal7yq2dhf0awwfi";
    };
    dependencies = [];

  };

  nim-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "nim-vim-2016-05-19";
    src = fetchgit {
      url = "https://github.com/zah/nim.vim";
      rev = "dcf25798f4a3f75e9538f9915959061edbff97cf";
      sha256 = "1jaiqkspfz2a4ny130dl0h6x9752flpcwwy0kscrqmlqf5fqiyvm";
    };
    dependencies = [];

  };

  deoplete-go = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "deoplete-go-2017-05-26";
    src = fetchgit {
      url = "https://github.com/zchee/deoplete-go";
      rev = "aef73fdf275053a6fb00c3f66d1f18821bc74bd3";
      sha256 = "1ixav3d78wy9zs9a8hg8yqk812srkbkwsaz17lg5sxjq6azljgvq";
    };
    dependencies = [];
    buildInputs = [ python3 ];
    buildPhase = ''
      pushd ./rplugin/python3/deoplete/ujson
      python3 setup.py build --build-base=$PWD/build --build-lib=$PWD/build
      popd
      find ./rplugin/ -name "ujson*.so" -exec mv -v {} ./rplugin/python3/ \;
    '';
  };

  deoplete-jedi = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "deoplete-jedi-2017-07-16";
    src = fetchgit {
      url = "https://github.com/zchee/deoplete-jedi";
      rev = "56528fd1238bbf2f9363f16710d0936703dc9eab";
      sha256 = "1kwwbr1w3865rlqs04hpxrqv67a14mzyf85pa29djmryi2156wxb";
    };
    dependencies = [];

  };

  goyo = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "goyo-2017-06-01";
    src = fetchgit {
      url = "git://github.com/junegunn/goyo.vim";
      rev = "5b8bd0378758c1d9550d8429bef24b3d6d78b592";
      sha256 = "0jh2gyf6v1vl12hygzwylzsj1ivx7r6xrd75k2wfsy91b2pm9srj";
    };
    dependencies = [];

  };

  gruvbox = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "gruvbox-2016-09-28";
    src = fetchgit {
      url = "git://github.com/morhetz/gruvbox";
      rev = "127c9d14d4bac1bac31e328b835a8919a255789c";
      sha256 = "19wg9143wvlynblpxm0cnk3ars2hgss3y745hligqgvfy308f7sm";
    };
    dependencies = [];

  };

  matchit-zip = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "matchit-zip";
    src = fetchurl {
      url = "http://www.vim.org/scripts/download_script.php?src_id=8196";
      name = "matchit.zip";
      sha256 = "1bbm8j1bhb70kagwdimwy9vcvlrz9ax5bk2a7wrmn4cy87f9xj4l";
    };
    buildInputs = [ unzip ];
    dependencies = [];
    meta = {
       url = "http://www.vim.org/scripts/script.php?script_id=39";
    };

    unpackPhase = ''
      (
       sourceRoot=d
       mkdir $sourceRoot; cd $sourceRoot;
       unzip $src
      )
    '';
  };

  pathogen = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "pathogen-2017-05-27";
    src = fetchgit {
      url = "git://github.com/tpope/vim-pathogen";
      rev = "ddfb1f14d7597e6aedc749be06b559a673c437ab";
      sha256 = "0fdd88gj75bzq6ifaddz3sl71w8ljnnci9npm04jmyvf048gnjg8";
    };
    dependencies = [];

  };

  quickfixstatus = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "quickfixstatus-2011-09-02";
    src = fetchgit {
      url = "git://github.com/dannyob/quickfixstatus";
      rev = "fd3875b914fc51bbefefa8c4995588c088163053";
      sha256 = "16vxhvyxq51y7wnx0c1fmdi2yb6kfr1pxijq65gxj8qwvbak2s3v";
    };
    dependencies = [];

  };

  rainbow_parentheses = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "rainbow_parentheses-2013-03-04";
    src = fetchgit {
      url = "git://github.com/kien/rainbow_parentheses.vim";
      rev = "eb8baa5428bde10ecc1cb14eed1d6e16f5f24695";
      sha256 = "1qw84imlhq4654mxazj7j3sp5g1j3yjxi496i08iix06dm15m5s7";
    };
    dependencies = [];

  };

  sensible = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "sensible-2017-05-09";
    src = fetchgit {
      url = "git://github.com/tpope/vim-sensible";
      rev = "49ee364222dc2a5a00dddf89fd61880e3e39d46a";
      sha256 = "0x9zn547hzzxjzplr2rkzhydh2y0a4fdkrwmdvw2yp203msyhcjx";
    };
    dependencies = [];

  };

  sleuth = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "sleuth-2017-07-23";
    src = fetchgit {
      url = "git://github.com/tpope/vim-sleuth";
      rev = "dfe0a33253c61dd8fac455baea4ec492e6cf0fe3";
      sha256 = "0576k4l2wbzy9frvv268vdix4k6iz9pw6n6626ifvg8hk6gbc5g9";
    };
    dependencies = [];

  };

  snipmate = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "snipmate-2017-04-20";
    src = fetchgit {
      url = "git://github.com/garbas/vim-snipmate";
      rev = "a9802f2351910f64b70fb10b63651e6ff6b8125e";
      sha256 = "1l7sc6lf66pkiy18aq9s3wk1dmvvvsy1063cc0bxich9xa8m34bj";
    };
    dependencies = ["vim-addon-mw-utils" "tlib"];

  };

  sourcemap = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "sourcemap-2012-09-19";
    src = fetchgit {
      url = "git://github.com/chikatoike/sourcemap.vim";
      rev = "0dd82d40faea2fdb0771067f46c01deb41610ba1";
      sha256 = "1gcgnynallz420911fdfm0ccbv3zs78p69nnh2ls1r4vlfp7g350";
    };
    dependencies = [];

  };

  surround = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "surround-2016-06-01";
    src = fetchgit {
      url = "git://github.com/tpope/vim-surround";
      rev = "e49d6c2459e0f5569ff2d533b4df995dd7f98313";
      sha256 = "1v0q2f1n8ngbja3wpjvqp2jh89pb5ij731qmm18k41nhgz6hhm46";
    };
    dependencies = [];

  };

  table-mode = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "table-mode-2017-04-20";
    src = fetchgit {
      url = "git://github.com/dhruvasagar/vim-table-mode";
      rev = "4e41af8e5f0bf53326d1b83c2feb1eff89fe90d4";
      sha256 = "0l83j3963lzkmn54vcagkwm2rhk96cl9v42l5r7zcgjign28cfzw";
    };
    dependencies = [];

  };

  taglist = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "taglist";
    src = fetchurl {
      url = "http://www.vim.org/scripts/download_script.php?src_id=19574";
      name = "taglist_46.zip";
      sha256 = "18cbv462vwg7vip2p99qlahm99hswav96cj4ki227kyi05q2lkjj";
    };
    buildInputs = [ unzip ];
    dependencies = [];
    meta = {
       url = "http://www.vim.org/scripts/script.php?script_id=273";
    };

    setSourceRoot = ''
      export sourceRoot=taglist
      mkdir taglist
      mv doc taglist
      mv plugin taglist
    '';
  };

  tlib = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "tlib-2017-05-20";
    src = fetchgit {
      url = "git://github.com/tomtom/tlib_vim";
      rev = "6f9d75b54478bcaab722d33cbec69d8a1fe49f32";
      sha256 = "1mh2m3c9xi7g650s06qxfpz57g493n0qjq35inad9y62yb1gsidm";
    };
    dependencies = [];

  };

  undotree = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "undotree-2017-03-24";
    src = fetchgit {
      url = "git://github.com/mbbill/undotree";
      rev = "ad08a88df70c1865b8c9ef6eeac5cdb051d2a18a";
      sha256 = "1i1sss8vzsym44amq19rfy95wm7143ks5h9imm7z7rah7xkcqv9l";
    };
    dependencies = [];

  };

  vim-addon-actions = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-actions-2014-09-22";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-actions";
      rev = "a5d20500fb8812958540cf17862bd73e7af64936";
      sha256 = "1wfkwr89sn2w97i94d0dqylcg9mr6pirjadi0a4l492nfnsh99bc";
    };
    dependencies = ["vim-addon-mw-utils" "tlib"];

  };

  vim-addon-async = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-async-2017-03-20";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-async";
      rev = "eca316a4480f68c2cb62128f3187dc7b2002afde";
      sha256 = "1lk8ma51dd0syi73vq5r4qk9cpy6cq3llizvh94hmxblfjpvrs7q";
    };
    dependencies = ["vim-addon-signs"];

  };

  vim-addon-background-cmd = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-background-cmd-2015-12-11";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-background-cmd";
      rev = "abf2abf339652d2bc79da81f9d131edfe2755f5a";
      sha256 = "0csy68x686l3x5ancidxb5b6prg9k7ikybqzq3klx0gs5rmksfy4";
    };
    dependencies = ["vim-addon-mw-utils"];

  };

  vim-addon-commenting = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-commenting-2013-06-10";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-commenting";
      rev = "b7cf748ac1c9bf555cbd347589e3b7196030d20b";
      sha256 = "0alak8h33vada2ckb0v06y82qlib5mhyc2yswlv1rqh8ypzhq3mc";
    };
    dependencies = [];

  };

  vim-addon-completion = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-completion-2015-02-10";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-completion";
      rev = "021c449a5ce1ce4ac0af5955e05b0279c1cc0e75";
      sha256 = "1ld059y2qwlc5bdfjm2p314s1qh31lxs54g944pw49r46s5nlslr";
    };
    dependencies = ["tlib"];

  };

  vim-addon-errorformats = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-errorformats-2014-11-05";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-errorformats";
      rev = "dcbb203ad5f56e47e75fdee35bc92e2ba69e1d28";
      sha256 = "159zqm69fxbxcv3b2y99g57bf20qrzsijcvb5rzy2njxah3049m1";
    };
    dependencies = [];

  };

  vim-addon-goto-thing-at-cursor = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-goto-thing-at-cursor-2012-01-11";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-goto-thing-at-cursor";
      rev = "f052e094bdb351829bf72ae3435af9042e09a6e4";
      sha256 = "1ksm2b0j80zn8sz2y227bpcx4jsv76lwgr2gpgy2drlyqhn2vlv0";
    };
    dependencies = ["tlib"];

  };

  vim-addon-local-vimrc = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-local-vimrc-2015-03-19";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-local-vimrc";
      rev = "6a27f95b35befa70cd0d049329cd0920566c764b";
      sha256 = "0n8lwl1gyak149p7jpgm0qbmfj8hcg8hirx3dxdhizw0yc47ws7h";
    };
    dependencies = [];

  };

  vim-addon-manager = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-manager-2017-05-07";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-manager";
      rev = "2434225ae48e608c2b6ac86c8da1c62209da746f";
      sha256 = "1fczkd05gir994614qmgscx131isr71bn0rwa6n3vgdbnhasz6bb";
    };
    dependencies = [];
    buildInputs = stdenv.lib.optional stdenv.isDarwin Cocoa;
  };

  vim-addon-mru = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-mru-2013-08-08";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-mru";
      rev = "e41e39bd9d1bf78ccfd8d5e1bc05ae5e1026c2bb";
      sha256 = "0q6rxr9nrp63kidr3m3c2z5sda4g813pzshg0scxkjr8dxwhzdqm";
    };
    dependencies = ["vim-addon-other" "vim-addon-mw-utils"];

  };

  vim-addon-mw-utils = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-mw-utils-2012-11-05";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-mw-utils";
      rev = "0c5612fa31ee434ba055e21c76f456244b3b5109";
      sha256 = "147s1k4n45d3x281vj35l26sv4waxjlpqdn83z3k9n51556h1d45";
    };
    dependencies = [];

  };

  vim-addon-nix = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-nix-2015-03-10";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-nix";
      rev = "2aed79ba5d8c5e6abd102de77e55e242f61b17f1";
      sha256 = "0zx1q9994py6jmm0qbbx6fc1dy5la8zfskkbvqqxssxrl5dx7vvi";
    };
    dependencies = ["vim-addon-completion" "vim-addon-goto-thing-at-cursor" "vim-addon-errorformats" "vim-addon-actions" "vim-addon-mw-utils" "tlib"];

  };

  vim-addon-other = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-other-2014-07-15";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-other";
      rev = "f78720c9cb5bf871cabb13c7cbf94378dbf0163b";
      sha256 = "0cjz7mlyfkkncas4ss7rwxb0q38ls1qw1p15hac1imscscsvyjc6";
    };
    dependencies = ["vim-addon-actions" "vim-addon-mw-utils"];

  };

  vim-addon-php-manual = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-php-manual-2015-01-01";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-php-manual";
      rev = "5f9810dd1f6e9f36a45f637ae6260ccff09256ff";
      sha256 = "1kc67f12wccqdza069b75lpcbqp4kv4r23i4mfz0ihwif5mfnhir";
    };
    dependencies = [];

  };

  vim-addon-signs = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-signs-2013-04-19";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-signs";
      rev = "17a49f293d18174ff09d1bfff5ba86e8eee8e8ae";
      sha256 = "0i4gfp30hmw1vqjl6zxjrgkca3ikdkcnjmma2mncjmcr6f59kjzy";
    };
    dependencies = [];

  };

  vim-addon-sql = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-sql-2017-02-11";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-sql";
      rev = "048a139af36829fce670c8ff80d3aad927557ee6";
      sha256 = "0ihm157sby6csdwsnw2gwh3jmm3prm1mxwgkx2hsfwlmpb1vwwm3";
    };
    dependencies = ["vim-addon-completion" "vim-addon-background-cmd" "tlib"];

  };

  vim-addon-syntax-checker = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-syntax-checker-2017-06-26";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-syntax-checker";
      rev = "739e5719b77c6aea3299c27fc1f4238ac54a8344";
      sha256 = "1rcn1ps06156nyglvxg6m7pn3vhvmnv5ad6kidp59hggyr5332i9";
    };
    dependencies = ["vim-addon-mw-utils" "tlib"];

  };

  vim-addon-toggle-buffer = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-toggle-buffer-2012-01-13";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-toggle-buffer";
      rev = "a1b38b9c5709cba666ed2d84ef06548f675c6b0b";
      sha256 = "1xq38kfdm36c34ln66znw841q797w5gm8bpq1x64bsf2h6n3ml03";
    };
    dependencies = ["vim-addon-mw-utils" "tlib"];

  };

  vim-addon-xdebug = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-xdebug-2014-08-29";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-xdebug";
      rev = "45f26407305b4ce6f8f5f37d2b5e6e4354104172";
      sha256 = "1i64ppdfp2qqq7vw1jf160mj4ikc04v39iazdab83xmiqjsh8ixw";
    };
    dependencies = ["WebAPI" "vim-addon-mw-utils" "vim-addon-signs" "vim-addon-async"];

  };

  vim-airline = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-airline-2017-07-21";
    src = fetchgit {
      url = "git://github.com/vim-airline/vim-airline";
      rev = "72e5f04f7c422e21cb6f6856c4e94cef25ea2288";
      sha256 = "0pkdlmil0lqwwi7anzn7r1zxxqbip9zy1pbwri031yksff6v2096";
    };
    dependencies = [];

  };

  vim-coffee-script = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-coffee-script-2017-03-03";
    src = fetchgit {
      url = "git://github.com/kchmck/vim-coffee-script";
      rev = "aace5c23d812a205c93e87ff79df72d9366928df";
      sha256 = "1saz5m3c329m2vk8ffhvxw4virz70k2qrjncwhvjpkik27jf75yy";
    };
    dependencies = [];

  };

  vim-easy-align = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-easy-align-2017-06-03";
    src = fetchgit {
      url = "git://github.com/junegunn/vim-easy-align";
      rev = "1cd724dc239c3a0f7a12e0fac85945cc3dbe07b0";
      sha256 = "0bqk1sdqamfgagh31a60c7gvvsvjpg1xys7ivqh62iqlny5i9774";
    };
    dependencies = [];

  };

  vim-gista = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-gista-2017-02-20";
    src = fetchgit {
      url = "git://github.com/lambdalisue/vim-gista";
      rev = "b6cd41d0eb480cd79e84f3da3703613d0cf94a6c";
      sha256 = "0bkzbppd3jdci4yvifb4sh05q20qn8cr3j9kqhxyc703s0l0lk2s";
    };
    dependencies = [];

  };

  vim-gitgutter = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-gitgutter-2017-06-08";
    src = fetchgit {
      url = "git://github.com/airblade/vim-gitgutter";
      rev = "dcac1f74ee5c26125363dca164463bde6657c838";
      sha256 = "0knkdv0sbdwf4p82g438l7pylwzxfbxcj44np3v15wr97w95wmlv";
    };
    dependencies = [];

  };

  vim-iced-coffee-script = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-iced-coffee-script-2013-12-27";
    src = fetchgit {
      url = "git://github.com/noc7c9/vim-iced-coffee-script";
      rev = "e42e0775fa4b1f8840c55cd36ac3d1cedbc1dea2";
      sha256 = "14yfirny359rlrr082il2ys3hxiyrbbk794rdxrs2lasjy8rb1f7";
    };
    dependencies = [];

  };

  vim-latex-live-preview = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-latex-live-preview-2017-07-19";
    src = fetchgit {
      url = "git://github.com/xuhdev/vim-latex-live-preview";
      rev = "172b03cd0677f1fe55abeab86fa4a4c484e4c3b5";
      sha256 = "1wgnq1kbx80xqwm9rx3z4i9fldj965046s4hh62rdi5585hh6aps";
    };
    dependencies = [];

  };

  vim-multiple-cursors = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-multiple-cursors-2017-06-02";
    src = fetchgit {
      url = "git://github.com/terryma/vim-multiple-cursors";
      rev = "3afc475cc64479a406ce73d3333df1f67db3c73f";
      sha256 = "04dijb4hgidypppphcy83bacmfrd9ikyjc761hqq6bl4kc49f5kc";
    };
    dependencies = [];

  };

  vim-signature = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-signature-2017-06-20";
    src = fetchgit {
      url = "git://github.com/kshenoy/vim-signature";
      rev = "c6decc68d644a66a34345ea09677469d6e482e1f";
      sha256 = "1iflyvskimq74hzb6l8mzjv3rh0i15bw9jv5x6arns86q3201l23";
    };
    dependencies = [];

  };

  vim-signify = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-signify-2017-07-19";
    src = fetchgit {
      url = "git://github.com/mhinz/vim-signify";
      rev = "748cb0ddab1b7e64bb81165c733a7b752b3d36e4";
      sha256 = "0kc4nbf3a7ab0an4r1j37bvzjarr4135qqhkz348r7zdhmqkyyfm";
    };
    dependencies = [];

  };

  vim-snippets = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-snippets-2017-07-07";
    src = fetchgit {
      url = "git://github.com/honza/vim-snippets";
      rev = "0817950a4fb8ccd48ec38a2b65cf046b597eecb3";
      sha256 = "0hxd96zl5gjkx5d381yzyrbahwbz3r9dljzn2cxbdbjsb7im6aks";
    };
    dependencies = [];

  };

  vim-webdevicons = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-webdevicons-2017-05-29";
    src = fetchgit {
      url = "git://github.com/ryanoasis/vim-devicons";
      rev = "153266275acc4f4615407a18e90f58780ebaef92";
      sha256 = "1zjrra0q5c7lmgxzlz7ddd7vi6k2vhz69fdy2s7d873nnmmd7kgn";
    };
    dependencies = [];

  };

  vim2hs = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim2hs-2014-04-16";
    src = fetchgit {
      url = "git://github.com/dag/vim2hs";
      rev = "f2afd55704bfe0a2d66e6b270d247e9b8a7b1664";
      sha256 = "18lqrl3hqb6cmizc04bbnsh8j0g761w2q8wascbzzfw80dmxy36b";
    };
    dependencies = [];

  };

  vimwiki = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vimwiki-2017-07-15";
    src = fetchgit {
      url = "git://github.com/vimwiki/vimwiki";
      rev = "976cbbcd23dcd19ddb5dc5544645da8a51dbdfe6";
      sha256 = "1mna3qavwj1jcjnvmw8hngrfccpk5krj2z0v2grp97i9m2kmkifx";
    };
    dependencies = [];

  };

  vinegar = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vinegar-2017-06-27";
    src = fetchgit {
      url = "git://github.com/tpope/vim-vinegar";
      rev = "c795cb739347cbddeeb288c3c35da9f140a513c9";
      sha256 = "1dcirb0b73s2l14ppn8mlh79pjpf9kgym9im05039ynr9rl83fv3";
    };
    dependencies = [];

  };

  vundle = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vundle-2017-06-08";
    src = fetchgit {
      url = "git://github.com/gmarik/vundle";
      rev = "6437ad6df4a3e6a87c5fb8bd2b8aadb277ec9c87";
      sha256 = "13k194g0rs5hz7ci0ys4gml71jily5hdd0yljzmmn8qjiq88v6p4";
    };
    dependencies = [];

  };

}
